from typing import Any

from pydantic import BaseModel, field_validator

class BasePatchModel(BaseModel):
    model_config = {"from_attributes": True}

    def is_set(self, key: str) -> bool:
        return key in self.model_fields_set


class BaseSnowflakeModel(BaseModel):
    """A base model with a Snowflake ID that is serialized as a string.
    Also sets `model_config.from_attributes` to `True`."""

    id: str

    @field_validator("id", mode="before")
    def transform_id_to_str(cls, value) -> str:
        return str(value)

    model_config = {"from_attributes": True}
